@@ -2,7 +2,7 @@
 
 
 class AtagException(Exception):
-    """Base error for atag_Thermostat."""
+    """Base error for AtagOne devices."""
 
 
 class Unauthorized(AtagException):
@@ -10,11 +10,7 @@ class Unauthorized(AtagException):
 
 
 class RequestError(AtagException):
-    """
-    Invalid request.
-    Unable to fulfill request.
-    Raised when host or API cannot be reached.
-    """
+    """Unable to fulfill request."""
 
 
 class ResponseError(AtagException):
@@ -39,5 +35,6 @@ ERRORS = {
 
 
 def raise_error(error, type=None):
+    """Raise the appropriate error."""
     cls = ERRORS.get(type, AtagException)
     raise cls(error)
